@@ -1,4 +1,4 @@
-## vim:textwidth=100:expandtab:shiftwidth=4:softtabstop=4
+# vim:textwidth=100:expandtab:shiftwidth=4:softtabstop=4
 
 
 #' Class to Store Current Meter Data
@@ -47,16 +47,34 @@ setClass("cm", contains="oce")
 #' @family things related to cm data
 NULL
 
-#' Extract Something From a CM Object
+#' Extract Something From a cm Object
 #'
 #' @param x a [cm-class] object.
 #'
+#' @section Details of the Specialized Method:
+#'
+#' * If `i` is `"?"`, then the return value is a list
+#' containing four items, each of which is a character vector
+#' holding the names of things that can be accessed with `[[`.
+#' The `data` and `metadata` items hold the names of
+#' entries in the object's data and metadata
+#' slots, respectively. The `dataDerived`
+#' and `metadataDerived` items are each NULL, because
+#' no derived values are defined by [cm-class] objects.
+#'
 #' @template sub_subTemplate
 #'
+#' @author Dan Kelley
+#'
 #' @family things related to cm data
 setMethod(f="[[",
           signature(x="cm", i="ANY", j="ANY"),
           definition=function(x, i, j, ...) {
+              if (i == "?")
+                  return(list(metadata=sort(names(x@metadata)),
+                          metadataDerived=NULL,
+                          data=sort(names(x@data)),
+                          dataDerived=NULL))
               callNextMethod()         # [[
           })
 
